import { useState, useEffect, useMemo } from "react";
const events = [
    "obsStreamingStarted",
    "obsStreamingStopped",
    "obsRecordingStarted",
    "obsRecordingStopped",
    "obsRecordingPaused",
    "obsRecordingUnpaused",
    /* @ts-ignore */
    "obsReplaybufferStarted",
    /* @ts-ignore */
    "obsReplaybufferStopped",
    "obsVirtualcamStarted",
    "obsVirtualcamStopped",
];
export function useOBSStatus() {
    const [status, setStatus] = useState(null);
    useEffect(() => {
        if (!window.obsstudio)
            return;
        obsstudio.getStatus(setStatus);
        const updateCallback = () => {
            obsstudio.getStatus(setStatus);
        };
        events.forEach((event) => {
            window.addEventListener(event, updateCallback);
        });
        return () => {
            events.forEach((event) => {
                window.removeEventListener(event, updateCallback);
            });
        };
    }, []);
    return status;
}
export function useOBSRecording() {
    const [recording, setRecording] = useState(false);
    const [paused, setPaused] = useState(false);
    const res = useMemo(() => {
        return {
            recording,
            recordingPaused: paused,
        };
    }, [recording, paused]);
    useEffect(() => {
        if (!window.obsstudio)
            return;
        obsstudio.getStatus((status) => {
            setRecording(status.recording);
            setPaused(status.recordingPaused);
        });
        const setRecordingTrue = () => {
            setRecording(true);
            setPaused(false);
        };
        const setRecordingFalse = () => {
            setRecording(false);
            setPaused(false);
        };
        const setPausedTrue = () => setPaused(true);
        const setPausedFalse = () => setPaused(false);
        window.addEventListener("obsRecordingStarted", setRecordingTrue);
        window.addEventListener("obsRecordingStopped", setRecordingFalse);
        window.addEventListener("obsRecordingPaused", setPausedTrue);
        window.addEventListener("obsRecordingUnpaused", setPausedFalse);
        return () => {
            window.removeEventListener("obsRecordingStarted", setRecordingTrue);
            window.removeEventListener("obsRecordingStopped", setRecordingFalse);
            window.removeEventListener("obsRecordingPaused", setPausedTrue);
            window.removeEventListener("obsRecordingUnpaused", setPausedFalse);
        };
    }, []);
    return res;
}
export function useOBSStreaming() {
    const [streaming, setStreaming] = useState(false);
    useEffect(() => {
        if (!window.obsstudio)
            return;
        obsstudio.getStatus((status) => {
            setStreaming(status.streaming);
        });
        const setStreamingTrue = () => setStreaming(true);
        const setStreamingFalse = () => setStreaming(false);
        window.addEventListener("obsStreamingStarted", setStreamingTrue);
        window.addEventListener("obsStreamingStopped", setStreamingFalse);
        return () => {
            window.removeEventListener("obsStreamingStarted", setStreamingTrue);
            window.removeEventListener("obsStreamingStopped", setStreamingFalse);
        };
    }, []);
    return streaming;
}
export function useOBSReplayBuffer() {
    const [replaybuffer, setReplayBuffer] = useState(false);
    useEffect(() => {
        if (!window.obsstudio)
            return;
        obsstudio.getStatus((status) => {
            setReplayBuffer(status.replaybuffer);
        });
        const setReplayBufferTrue = () => setReplayBuffer(true);
        const setReplayBufferFalse = () => setReplayBuffer(false);
        window.addEventListener("obsReplaybufferStarted", setReplayBufferTrue);
        window.addEventListener("obsReplaybufferStopped", setReplayBufferFalse);
        return () => {
            window.removeEventListener("obsReplaybufferStarted", setReplayBufferTrue);
            window.removeEventListener("obsReplaybufferStopped", setReplayBufferFalse);
        };
    }, []);
    return replaybuffer;
}
export function useOBSVirtualcam() {
    const [virtualcam, setVirtualcam] = useState(false);
    useEffect(() => {
        if (!window.obsstudio)
            return;
        obsstudio.getStatus((status) => {
            setVirtualcam(status.virtualcam);
        });
        const setVirtualcamTrue = () => setVirtualcam(true);
        const setVirtualcamFalse = () => setVirtualcam(false);
        window.addEventListener("obsVirtualcamStarted", setVirtualcamTrue);
        window.addEventListener("obsVirtualcamStopped", setVirtualcamFalse);
        return () => {
            window.removeEventListener("obsVirtualcamStarted", setVirtualcamTrue);
            window.removeEventListener("obsVirtualcamStopped", setVirtualcamFalse);
        };
    }, []);
    return virtualcam;
}
