"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useOBSVirtualcam = exports.useOBSReplayBuffer = exports.useOBSStreaming = exports.useOBSRecording = exports.useOBSStatus = void 0;
var react_1 = require("react");
var events = [
    "obsStreamingStarted",
    "obsStreamingStopped",
    "obsRecordingStarted",
    "obsRecordingStopped",
    "obsRecordingPaused",
    "obsRecordingUnpaused",
    /* @ts-ignore */
    "obsReplaybufferStarted",
    /* @ts-ignore */
    "obsReplaybufferStopped",
    "obsVirtualcamStarted",
    "obsVirtualcamStopped",
];
function useOBSStatus() {
    var _a = (0, react_1.useState)(null), status = _a[0], setStatus = _a[1];
    (0, react_1.useEffect)(function () {
        if (!window.obsstudio)
            return;
        obsstudio.getStatus(setStatus);
        var updateCallback = function () {
            obsstudio.getStatus(setStatus);
        };
        events.forEach(function (event) {
            window.addEventListener(event, updateCallback);
        });
        return function () {
            events.forEach(function (event) {
                window.removeEventListener(event, updateCallback);
            });
        };
    }, []);
    return status;
}
exports.useOBSStatus = useOBSStatus;
function useOBSRecording() {
    var _a = (0, react_1.useState)(false), recording = _a[0], setRecording = _a[1];
    var _b = (0, react_1.useState)(false), paused = _b[0], setPaused = _b[1];
    var res = (0, react_1.useMemo)(function () {
        return {
            recording: recording,
            recordingPaused: paused,
        };
    }, [recording, paused]);
    (0, react_1.useEffect)(function () {
        if (!window.obsstudio)
            return;
        obsstudio.getStatus(function (status) {
            setRecording(status.recording);
            setPaused(status.recordingPaused);
        });
        var setRecordingTrue = function () {
            setRecording(true);
            setPaused(false);
        };
        var setRecordingFalse = function () {
            setRecording(false);
            setPaused(false);
        };
        var setPausedTrue = function () { return setPaused(true); };
        var setPausedFalse = function () { return setPaused(false); };
        window.addEventListener("obsRecordingStarted", setRecordingTrue);
        window.addEventListener("obsRecordingStopped", setRecordingFalse);
        window.addEventListener("obsRecordingPaused", setPausedTrue);
        window.addEventListener("obsRecordingUnpaused", setPausedFalse);
        return function () {
            window.removeEventListener("obsRecordingStarted", setRecordingTrue);
            window.removeEventListener("obsRecordingStopped", setRecordingFalse);
            window.removeEventListener("obsRecordingPaused", setPausedTrue);
            window.removeEventListener("obsRecordingUnpaused", setPausedFalse);
        };
    }, []);
    return res;
}
exports.useOBSRecording = useOBSRecording;
function useOBSStreaming() {
    var _a = (0, react_1.useState)(false), streaming = _a[0], setStreaming = _a[1];
    (0, react_1.useEffect)(function () {
        if (!window.obsstudio)
            return;
        obsstudio.getStatus(function (status) {
            setStreaming(status.streaming);
        });
        var setStreamingTrue = function () { return setStreaming(true); };
        var setStreamingFalse = function () { return setStreaming(false); };
        window.addEventListener("obsStreamingStarted", setStreamingTrue);
        window.addEventListener("obsStreamingStopped", setStreamingFalse);
        return function () {
            window.removeEventListener("obsStreamingStarted", setStreamingTrue);
            window.removeEventListener("obsStreamingStopped", setStreamingFalse);
        };
    }, []);
    return streaming;
}
exports.useOBSStreaming = useOBSStreaming;
function useOBSReplayBuffer() {
    var _a = (0, react_1.useState)(false), replaybuffer = _a[0], setReplayBuffer = _a[1];
    (0, react_1.useEffect)(function () {
        if (!window.obsstudio)
            return;
        obsstudio.getStatus(function (status) {
            setReplayBuffer(status.replaybuffer);
        });
        var setReplayBufferTrue = function () { return setReplayBuffer(true); };
        var setReplayBufferFalse = function () { return setReplayBuffer(false); };
        window.addEventListener("obsReplaybufferStarted", setReplayBufferTrue);
        window.addEventListener("obsReplaybufferStopped", setReplayBufferFalse);
        return function () {
            window.removeEventListener("obsReplaybufferStarted", setReplayBufferTrue);
            window.removeEventListener("obsReplaybufferStopped", setReplayBufferFalse);
        };
    }, []);
    return replaybuffer;
}
exports.useOBSReplayBuffer = useOBSReplayBuffer;
function useOBSVirtualcam() {
    var _a = (0, react_1.useState)(false), virtualcam = _a[0], setVirtualcam = _a[1];
    (0, react_1.useEffect)(function () {
        if (!window.obsstudio)
            return;
        obsstudio.getStatus(function (status) {
            setVirtualcam(status.virtualcam);
        });
        var setVirtualcamTrue = function () { return setVirtualcam(true); };
        var setVirtualcamFalse = function () { return setVirtualcam(false); };
        window.addEventListener("obsVirtualcamStarted", setVirtualcamTrue);
        window.addEventListener("obsVirtualcamStopped", setVirtualcamFalse);
        return function () {
            window.removeEventListener("obsVirtualcamStarted", setVirtualcamTrue);
            window.removeEventListener("obsVirtualcamStopped", setVirtualcamFalse);
        };
    }, []);
    return virtualcam;
}
exports.useOBSVirtualcam = useOBSVirtualcam;
